==> onos-yang-serializers-xml-2.2.0-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/telinkinfoattributes/InterfaceSwitchingCapabilityKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes;

import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.SwitchingCapabilities;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of interfaceSwitchingCapability.
 */
public class InterfaceSwitchingCapabilityKeys implements KeyInfo<DefaultInterfaceSwitchingCapability> {
    protected Class<? extends SwitchingCapabilities> switchingCapability;
    /**
     * Returns the attribute switchingCapability.
     *
     * @return switchingCapability value of switchingCapability
     */
    public Class<? extends SwitchingCapabilities> switchingCapability() {
        return switchingCapability;
    }

    /**
     * Sets the value to attribute switchingCapability.
     *
     * @param switchingCapability value of switchingCapability
     */
    public void switchingCapability(Class<? extends SwitchingCapabilities> switchingCapability) {
        this.switchingCapability = switchingCapability;
    }


    @Override
    public int hashCode() {
        return Objects.hash(switchingCapability);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof InterfaceSwitchingCapabilityKeys) {
            InterfaceSwitchingCapabilityKeys other = (InterfaceSwitchingCapabilityKeys) obj;
            return
                Objects.equals(switchingCapability, other.switchingCapability);
        }
        return false;
    }
}

==> onos-yang-serializers-xml-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/telinkinfoattributes/InterfaceSwitchingCapabilityKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes;

import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.SwitchingCapabilities;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of interfaceSwitchingCapability.
 */
public class InterfaceSwitchingCapabilityKeys implements KeyInfo<DefaultInterfaceSwitchingCapability> {
    protected Class<? extends SwitchingCapabilities> switchingCapability;
    /**
     * Returns the attribute switchingCapability.
     *
     * @return switchingCapability value of switchingCapability
     */
    public Class<? extends SwitchingCapabilities> switchingCapability() {
        return switchingCapability;
    }

    /**
     * Sets the value to attribute switchingCapability.
     *
     * @param switchingCapability value of switchingCapability
     */
    public void switchingCapability(Class<? extends SwitchingCapabilities> switchingCapability) {
        this.switchingCapability = switchingCapability;
    }


    @Override
    public int hashCode() {
        return Objects.hash(switchingCapability);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof InterfaceSwitchingCapabilityKeys) {
            InterfaceSwitchingCapabilityKeys other = (InterfaceSwitchingCapabilityKeys) obj;
            return
                Objects.deepEquals(switchingCapability, other.switchingCapability);
        }
        return false;
    }
}
